@@ -17,7 +17,10 @@ from types import MethodType
 
 from flask import url_for, request, current_app
 from flask import make_response as original_flask_make_response
-from flask.helpers import _endpoint_from_view_func
+try:
+    from flask.helpers import _endpoint_from_view_func
+except ImportError:
+    from flask.scaffold import _endpoint_from_view_func
 from flask.signals import got_request_exception
 
 from jsonschema import RefResolver
@@ -94,6 +97,9 @@ class Api(object):
     :param FormatChecker format_checker: A jsonschema.FormatChecker object that is hooked into
         the Model validator. A default or a custom FormatChecker can be provided (e.g., with custom
         checkers), otherwise the default action is to not enforce any format validation.
+    :param url_scheme: If set to a string (e.g. http, https), then the specs_url and base_url will explicitly use this
+        scheme regardless of how the application is deployed. This is necessary for some deployments behind a reverse
+        proxy.
     """
 
     def __init__(
@@ -123,6 +129,7 @@ class Api(object):
         catch_all_404s=False,
         serve_challenge_on_401=False,
         format_checker=None,
+        url_scheme=None,
         **kwargs
     ):
         self.version = version
@@ -178,6 +185,7 @@ class Api(object):
             api=self,
             path="/",
         )
+        self.url_scheme = url_scheme
         if app is not None:
             self.app = app
             self.init_app(app)
@@ -198,7 +206,9 @@ class Api(object):
         :param str contact: A contact email for the API (used in Swagger documentation)
         :param str license: The license associated to the API (used in Swagger documentation)
         :param str license_url: The license page URL (used in Swagger documentation)
-
+        :param url_scheme: If set to a string (e.g. http, https), then the specs_url and base_url will explicitly use
+            this scheme regardless of how the application is deployed. This is necessary for some deployments behind a
+            reverse proxy.
         """
         self.app = app
         self.title = kwargs.get("title", self.title)
@@ -209,6 +219,7 @@ class Api(object):
         self.contact_email = kwargs.get("contact_email", self.contact_email)
         self.license = kwargs.get("license", self.license)
         self.license_url = kwargs.get("license_url", self.license_url)
+        self.url_scheme = kwargs.get("url_scheme", self.url_scheme)
         self._add_specs = kwargs.get("add_specs", True)
 
         # If app is a blueprint, defer the initialization
@@ -220,7 +231,6 @@ class Api(object):
         else:
             self.blueprint = app
 
-
     def _init_app(self, app):
         """
         Perform initialization actions with the given :class:`flask.Flask` object.
@@ -261,7 +271,6 @@ class Api(object):
                 DeprecationWarning
             )
 
-
     def __getattr__(self, name):
         try:
             return getattr(self.default_namespace, name)
@@ -515,11 +524,16 @@ class Api(object):
     @property
     def specs_url(self):
         """
-        The Swagger specifications relative url (ie. `swagger.json`)
+        The Swagger specifications relative url (ie. `swagger.json`). If
+        the spec_url_scheme attribute is set, then the full url is provided instead
+        (e.g. http://localhost/swaggger.json).
 
         :rtype: str
         """
-        return url_for(self.endpoint("specs"))
+        external = None if self.url_scheme is None else True
+        return url_for(
+            self.endpoint("specs"), _scheme=self.url_scheme, _external=external
+        )
 
     @property
     def base_url(self):
@@ -528,7 +542,7 @@ class Api(object):
 
         :rtype: str
         """
-        return url_for(self.endpoint("root"), _external=True)
+        return url_for(self.endpoint("root"), _scheme=self.url_scheme, _external=True)
 
     @property
     def base_path(self):
@@ -666,7 +680,7 @@ class Api(object):
         if (
             not isinstance(e, HTTPException)
             and current_app.propagate_exceptions
-            and not isinstance(e, tuple(self.error_handlers.keys()))
+            and not isinstance(e, tuple(self._own_and_child_error_handlers.keys()))
         ):
 
             exc_type, exc_value, tb = sys.exc_info()
