@@ -18,7 +18,7 @@ from flask import current_app
 from werkzeug.routing import parse_rule
 
 from . import fields
-from .model import Model, ModelBase
+from .model import Model, ModelBase, OrderedModel
 from .reqparse import RequestParser
 from .utils import merge, not_none, not_none_sorted
 from ._http import HTTPStatus
@@ -241,6 +241,11 @@ class Swagger(object):
                     )
                     paths[path] = serialized
 
+        # register all models if required
+        if current_app.config["RESTX_INCLUDE_ALL_MODELS"]:
+            for m in self.api.models:
+                self.register_model(m)
+
         # merge in the top-level authorizations
         for ns in self.api.namespaces:
             if ns.authorizations:
@@ -652,11 +657,13 @@ class Swagger(object):
         if name not in self.api.models:
             raise ValueError("Model {0} not registered".format(name))
         specs = self.api.models[name]
+        if name in self._registered_models:
+            return ref(model)
         self._registered_models[name] = specs
         if isinstance(specs, ModelBase):
             for parent in specs.__parents__:
                 self.register_model(parent)
-        if isinstance(specs, Model):
+        if isinstance(specs, (Model, OrderedModel)):
             for field in itervalues(specs):
                 self.register_field(field)
         return ref(model)
